@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.9.5;
+package Pcore::WebDriver v0.9.6;
 
 use Pcore -dist, -const, -class, -result,
   -export => {
@@ -248,21 +248,21 @@ sub _get_chrome_cmd ( $self, $args ) {
     $args->{bin} = $ENV->share->get( $MSWIN ? '/bin/webdriver/chromedriver.exe' : '/bin/webdriver/chromedriver-linux-x64' ) if !$args->{bin};
 
     my $cmd = [    #
-        $self->{xvfb} ? ( 'xvfb-run', '-d', '--server-args=-screen 0 1280x720x8' ) : (),
-        $args->{bin},
+        $self->{xvfb} ? ( 'xvfb-run', '-d', '--server-args="-screen 0 1280x720x8"' ) : (),
+        qq["$args->{bin}"],
         "--port=$args->{port}",
         '--silent',
         defined $args->{args} ? $args->{args}->@* : (),
     ];
 
-    return $cmd;
+    return join q[ ], $cmd->@*;
 }
 
 sub _get_phantomjs_cmd ( $self, $args ) {
     $args->{bin} = $ENV->share->get( $MSWIN ? '/bin/webdriver/phantomjs.exe' : '/bin/webdriver/phantomjs-linux-x64/bin/phantomjs' );
 
     my $cmd = [    #
-        $args->{bin},
+        qq["$args->{bin}"],
         "--webdriver=$args->{host}:$args->{port}",
         '--webdriver-loglevel=NONE',
         '--debug=no',
@@ -271,7 +271,7 @@ sub _get_phantomjs_cmd ( $self, $args ) {
         defined $args->{args} ? $args->{args}->@* : (),
     ];
 
-    return $cmd;
+    return join q[ ], $cmd->@*;
 }
 
 sub new_session ( $self, @args ) {
